==> zio-aws-accessanalyzer_2.13-5.17.155.2-sources.jar: zio/aws/accessanalyzer/model/AccessPreviewFinding.scala <==
package zio.aws.accessanalyzer.model
import zio.aws.accessanalyzer.model.primitives.{
  AccessPreviewFindingId,
  FindingId,
  Timestamp
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class AccessPreviewFinding(
    action: Option[Iterable[String]] = None,
    changeType: zio.aws.accessanalyzer.model.FindingChangeType,
    condition: Option[Map[String, String]] = None,
    createdAt: Timestamp,
    error: Option[String] = None,
    existingFindingId: Option[FindingId] = None,
    existingFindingStatus: Option[zio.aws.accessanalyzer.model.FindingStatus] =
      None,
    id: AccessPreviewFindingId,
    isPublic: Option[Boolean] = None,
    principal: Option[Map[String, String]] = None,
    resource: Option[String] = None,
    resourceOwnerAccount: String,
    resourceType: zio.aws.accessanalyzer.model.ResourceType,
    sources: Option[Iterable[zio.aws.accessanalyzer.model.FindingSource]] =
      None,
    status: zio.aws.accessanalyzer.model.FindingStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding = {
    import AccessPreviewFinding.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding
      .builder()
      .optionallyWith(
        action.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.action)
      .changeType(changeType.unwrap)
      .optionallyWith(
        condition.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.condition)
      .createdAt(Timestamp.unwrap(createdAt): Instant)
      .optionallyWith(error.map(value => value: java.lang.String))(_.error)
      .optionallyWith(
        existingFindingId.map(value =>
          FindingId.unwrap(value): java.lang.String
        )
      )(_.existingFindingId)
      .optionallyWith(existingFindingStatus.map(value => value.unwrap))(
        _.existingFindingStatus
      )
      .id(AccessPreviewFindingId.unwrap(id): java.lang.String)
      .optionallyWith(isPublic.map(value => value: java.lang.Boolean))(
        _.isPublic
      )
      .optionallyWith(
        principal.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.principal)
      .optionallyWith(resource.map(value => value: java.lang.String))(
        _.resource
      )
      .resourceOwnerAccount(resourceOwnerAccount: java.lang.String)
      .resourceType(resourceType.unwrap)
      .optionallyWith(
        sources.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.sources)
      .status(status.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.accessanalyzer.model.AccessPreviewFinding.ReadOnly =
    zio.aws.accessanalyzer.model.AccessPreviewFinding.wrap(buildAwsValue())
}
object AccessPreviewFinding {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.accessanalyzer.model.AccessPreviewFinding =
      zio.aws.accessanalyzer.model.AccessPreviewFinding(
        action.map(value => value),
        changeType,
        condition.map(value => value),
        createdAt,
        error.map(value => value),
        existingFindingId.map(value => value),
        existingFindingStatus.map(value => value),
        id,
        isPublic.map(value => value),
        principal.map(value => value),
        resource.map(value => value),
        resourceOwnerAccount,
        resourceType,
        sources.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        status
      )
    def action: Option[List[String]]
    def changeType: zio.aws.accessanalyzer.model.FindingChangeType
    def condition: Option[Map[String, String]]
    def createdAt: Timestamp
    def error: Option[String]
    def existingFindingId: Option[FindingId]
    def existingFindingStatus
        : Option[zio.aws.accessanalyzer.model.FindingStatus]
    def id: AccessPreviewFindingId
    def isPublic: Option[Boolean]
    def principal: Option[Map[String, String]]
    def resource: Option[String]
    def resourceOwnerAccount: String
    def resourceType: zio.aws.accessanalyzer.model.ResourceType
    def sources
        : Option[List[zio.aws.accessanalyzer.model.FindingSource.ReadOnly]]
    def status: zio.aws.accessanalyzer.model.FindingStatus
    def getAction: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("action", action)
    def getChangeType
        : ZIO[Any, Nothing, zio.aws.accessanalyzer.model.FindingChangeType] =
      ZIO.succeed(changeType)
    def getCondition: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("condition", condition)
    def getCreatedAt: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createdAt)
    def getError: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("error", error)
    def getExistingFindingId: ZIO[Any, AwsError, FindingId] =
      AwsError.unwrapOptionField("existingFindingId", existingFindingId)
    def getExistingFindingStatus
        : ZIO[Any, AwsError, zio.aws.accessanalyzer.model.FindingStatus] =
      AwsError.unwrapOptionField("existingFindingStatus", existingFindingStatus)
    def getId: ZIO[Any, Nothing, AccessPreviewFindingId] = ZIO.succeed(id)
    def getIsPublic: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isPublic", isPublic)
    def getPrincipal: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("principal", principal)
    def getResource: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("resource", resource)
    def getResourceOwnerAccount: ZIO[Any, Nothing, String] =
      ZIO.succeed(resourceOwnerAccount)
    def getResourceType
        : ZIO[Any, Nothing, zio.aws.accessanalyzer.model.ResourceType] =
      ZIO.succeed(resourceType)
    def getSources: ZIO[Any, AwsError, List[
      zio.aws.accessanalyzer.model.FindingSource.ReadOnly
    ]] = AwsError.unwrapOptionField("sources", sources)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.accessanalyzer.model.FindingStatus] =
      ZIO.succeed(status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding
  ) extends zio.aws.accessanalyzer.model.AccessPreviewFinding.ReadOnly {
    override val action: Option[List[String]] = scala
      .Option(impl.action())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val changeType: zio.aws.accessanalyzer.model.FindingChangeType =
      zio.aws.accessanalyzer.model.FindingChangeType.wrap(impl.changeType())
    override val condition: Option[Map[String, String]] = scala
      .Option(impl.condition())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val createdAt: Timestamp =
      zio.aws.accessanalyzer.model.primitives.Timestamp(impl.createdAt())
    override val error: Option[String] =
      scala.Option(impl.error()).map(value => value: String)
    override val existingFindingId: Option[FindingId] = scala
      .Option(impl.existingFindingId())
      .map(value => zio.aws.accessanalyzer.model.primitives.FindingId(value))
    override val existingFindingStatus
        : Option[zio.aws.accessanalyzer.model.FindingStatus] = scala
      .Option(impl.existingFindingStatus())
      .map(value => zio.aws.accessanalyzer.model.FindingStatus.wrap(value))
    override val id: AccessPreviewFindingId =
      zio.aws.accessanalyzer.model.primitives.AccessPreviewFindingId(impl.id())
    override val isPublic: Option[Boolean] =
      scala.Option(impl.isPublic()).map(value => value: Boolean)
    override val principal: Option[Map[String, String]] = scala
      .Option(impl.principal())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: String) -> (value: String)
          })
          .toMap
      )
    override val resource: Option[String] =
      scala.Option(impl.resource()).map(value => value: String)
    override val resourceOwnerAccount: String =
      impl.resourceOwnerAccount(): String
    override val resourceType: zio.aws.accessanalyzer.model.ResourceType =
      zio.aws.accessanalyzer.model.ResourceType.wrap(impl.resourceType())
    override val sources
        : Option[List[zio.aws.accessanalyzer.model.FindingSource.ReadOnly]] =
      scala
        .Option(impl.sources())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.accessanalyzer.model.FindingSource.wrap(item)
          }.toList
        )
    override val status: zio.aws.accessanalyzer.model.FindingStatus =
      zio.aws.accessanalyzer.model.FindingStatus.wrap(impl.status())
  }
  def wrap(
      impl: software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding
  ): zio.aws.accessanalyzer.model.AccessPreviewFinding.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-accessanalyzer_2.13-5.17.176.1-sources.jar: zio/aws/accessanalyzer/model/AccessPreviewFinding.scala <==
package zio.aws.accessanalyzer.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.accessanalyzer.model.primitives.{
  AccessPreviewFindingId,
  FindingId,
  Timestamp
}
import scala.jdk.CollectionConverters._
final case class AccessPreviewFinding(
    action: Optional[Iterable[String]] = Optional.Absent,
    changeType: zio.aws.accessanalyzer.model.FindingChangeType,
    condition: Optional[Map[String, String]] = Optional.Absent,
    createdAt: Timestamp,
    error: Optional[String] = Optional.Absent,
    existingFindingId: Optional[FindingId] = Optional.Absent,
    existingFindingStatus: Optional[
      zio.aws.accessanalyzer.model.FindingStatus
    ] = Optional.Absent,
    id: AccessPreviewFindingId,
    isPublic: Optional[Boolean] = Optional.Absent,
    principal: Optional[Map[String, String]] = Optional.Absent,
    resource: Optional[String] = Optional.Absent,
    resourceOwnerAccount: String,
    resourceType: zio.aws.accessanalyzer.model.ResourceType,
    sources: Optional[Iterable[zio.aws.accessanalyzer.model.FindingSource]] =
      Optional.Absent,
    status: zio.aws.accessanalyzer.model.FindingStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding = {
    import AccessPreviewFinding.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding
      .builder()
      .optionallyWith(
        action.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.action)
      .changeType(changeType.unwrap)
      .optionallyWith(
        condition.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.condition)
      .createdAt(Timestamp.unwrap(createdAt): Instant)
      .optionallyWith(error.map(value => value: java.lang.String))(_.error)
      .optionallyWith(
        existingFindingId.map(value =>
          FindingId.unwrap(value): java.lang.String
        )
      )(_.existingFindingId)
      .optionallyWith(existingFindingStatus.map(value => value.unwrap))(
        _.existingFindingStatus
      )
      .id(AccessPreviewFindingId.unwrap(id): java.lang.String)
      .optionallyWith(isPublic.map(value => value: java.lang.Boolean))(
        _.isPublic
      )
      .optionallyWith(
        principal.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (value: java.lang.String)
            })
            .asJava
        )
      )(_.principal)
      .optionallyWith(resource.map(value => value: java.lang.String))(
        _.resource
      )
      .resourceOwnerAccount(resourceOwnerAccount: java.lang.String)
      .resourceType(resourceType.unwrap)
      .optionallyWith(
        sources.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.sources)
      .status(status.unwrap)
      .build()
  }
  def asReadOnly: zio.aws.accessanalyzer.model.AccessPreviewFinding.ReadOnly =
    zio.aws.accessanalyzer.model.AccessPreviewFinding.wrap(buildAwsValue())
}
object AccessPreviewFinding {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.accessanalyzer.model.AccessPreviewFinding =
      zio.aws.accessanalyzer.model.AccessPreviewFinding(
        action.map(value => value),
        changeType,
        condition.map(value => value),
        createdAt,
        error.map(value => value),
        existingFindingId.map(value => value),
        existingFindingStatus.map(value => value),
        id,
        isPublic.map(value => value),
        principal.map(value => value),
        resource.map(value => value),
        resourceOwnerAccount,
        resourceType,
        sources.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        status
      )
    def action: Optional[List[String]]
    def changeType: zio.aws.accessanalyzer.model.FindingChangeType
    def condition: Optional[Map[String, String]]
    def createdAt: Timestamp
    def error: Optional[String]
    def existingFindingId: Optional[FindingId]
    def existingFindingStatus
        : Optional[zio.aws.accessanalyzer.model.FindingStatus]
    def id: AccessPreviewFindingId
    def isPublic: Optional[Boolean]
    def principal: Optional[Map[String, String]]
    def resource: Optional[String]
    def resourceOwnerAccount: String
    def resourceType: zio.aws.accessanalyzer.model.ResourceType
    def sources
        : Optional[List[zio.aws.accessanalyzer.model.FindingSource.ReadOnly]]
    def status: zio.aws.accessanalyzer.model.FindingStatus
    def getAction: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("action", action)
    def getChangeType
        : ZIO[Any, Nothing, zio.aws.accessanalyzer.model.FindingChangeType] =
      ZIO.succeed(changeType)
    def getCondition: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("condition", condition)
    def getCreatedAt: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createdAt)
    def getError: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("error", error)
    def getExistingFindingId: ZIO[Any, AwsError, FindingId] =
      AwsError.unwrapOptionField("existingFindingId", existingFindingId)
    def getExistingFindingStatus
        : ZIO[Any, AwsError, zio.aws.accessanalyzer.model.FindingStatus] =
      AwsError.unwrapOptionField("existingFindingStatus", existingFindingStatus)
    def getId: ZIO[Any, Nothing, AccessPreviewFindingId] = ZIO.succeed(id)
    def getIsPublic: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isPublic", isPublic)
    def getPrincipal: ZIO[Any, AwsError, Map[String, String]] =
      AwsError.unwrapOptionField("principal", principal)
    def getResource: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("resource", resource)
    def getResourceOwnerAccount: ZIO[Any, Nothing, String] =
      ZIO.succeed(resourceOwnerAccount)
    def getResourceType
        : ZIO[Any, Nothing, zio.aws.accessanalyzer.model.ResourceType] =
      ZIO.succeed(resourceType)
    def getSources: ZIO[Any, AwsError, List[
      zio.aws.accessanalyzer.model.FindingSource.ReadOnly
    ]] = AwsError.unwrapOptionField("sources", sources)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.accessanalyzer.model.FindingStatus] =
      ZIO.succeed(status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding
  ) extends zio.aws.accessanalyzer.model.AccessPreviewFinding.ReadOnly {
    override val action: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.action())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val changeType: zio.aws.accessanalyzer.model.FindingChangeType =
      zio.aws.accessanalyzer.model.FindingChangeType.wrap(impl.changeType())
    override val condition: Optional[Map[String, String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.condition())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> (value: String)
            })
            .toMap
        )
    override val createdAt: Timestamp =
      zio.aws.accessanalyzer.model.primitives.Timestamp(impl.createdAt())
    override val error: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.error())
      .map(value => value: String)
    override val existingFindingId: Optional[FindingId] = zio.aws.core.internal
      .optionalFromNullable(impl.existingFindingId())
      .map(value => zio.aws.accessanalyzer.model.primitives.FindingId(value))
    override val existingFindingStatus
        : Optional[zio.aws.accessanalyzer.model.FindingStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.existingFindingStatus())
        .map(value => zio.aws.accessanalyzer.model.FindingStatus.wrap(value))
    override val id: AccessPreviewFindingId =
      zio.aws.accessanalyzer.model.primitives.AccessPreviewFindingId(impl.id())
    override val isPublic: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.isPublic())
      .map(value => value: Boolean)
    override val principal: Optional[Map[String, String]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.principal())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> (value: String)
            })
            .toMap
        )
    override val resource: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.resource())
      .map(value => value: String)
    override val resourceOwnerAccount: String =
      impl.resourceOwnerAccount(): String
    override val resourceType: zio.aws.accessanalyzer.model.ResourceType =
      zio.aws.accessanalyzer.model.ResourceType.wrap(impl.resourceType())
    override val sources
        : Optional[List[zio.aws.accessanalyzer.model.FindingSource.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sources())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.accessanalyzer.model.FindingSource.wrap(item)
          }.toList
        )
    override val status: zio.aws.accessanalyzer.model.FindingStatus =
      zio.aws.accessanalyzer.model.FindingStatus.wrap(impl.status())
  }
  def wrap(
      impl: software.amazon.awssdk.services.accessanalyzer.model.AccessPreviewFinding
  ): zio.aws.accessanalyzer.model.AccessPreviewFinding.ReadOnly = new Wrapper(
    impl
  )
}
